``zope.annotation`` README
==========================

.. image:: https://travis-ci.org/zopefoundation/zope.annotation.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.annotation

This package provides a mechanism to store additional information about
objects without need to modify object class.
